@@ -9,7 +9,7 @@ import traceback
 import types
 
 import vyxal.encoding
-from vyxal.context import Context
+from vyxal.context import Context, TranspilationOptions
 from vyxal.elements import *
 from vyxal.helpers import *
 from vyxal.transpile import transpile
@@ -45,6 +45,7 @@ FLAG_STRING = """ALL flags should be used as is (no '-' prefix)
     Ṡ    Treat all inputs as strings
     R    Treat numbers as ranges if ever used as an iterable
     D    Treat all strings as raw strings (don't decompress strings)
+    U    Treat all strings as UTF-8 byte sequences (also don't decompress strings)
     Ṫ    Print the sum of the entire stack
     ṡ    Print the entire stack, joined on spaces
     Z    With four argument vectorization where all arguments are lists, use zip(zip(a, b), zip(c, d)) instead of zip(a, b, c, d)
@@ -59,6 +60,7 @@ FLAG_STRING = """ALL flags should be used as is (no '-' prefix)
     ?    If there is empty input, treat it as 0 instead of empty string.
     2    Make the default arity of lambdas 2
     3    Make the default arity of lambdas 3
+    A    Run test cases on all inputs
     …    Limit list output to the first 100 items of that list
     5    Make the interpreter timeout after 5 seconds (online interpreter only)
     b    Make the interpreter timeout after 15 seconds (online interpreter only)
@@ -83,6 +85,33 @@ def execute_vyxal(file_name, flags, inputs, output_var=None, online_mode=False):
         vy_print(FLAG_STRING, ctx=ctx)
         sys.exit(0)
 
+    if "A" in flags:
+        for inp in inputs:
+            try:
+                inps = ast.literal_eval(inp)
+                if isinstance(inps, tuple):
+                    inps = list(inps)
+                else:
+                    inps = [inps]
+                inps = [vyxalify(x) for x in inps]
+            except:
+                inps = inp.split(", ")
+            temp_ctx = Context()
+            temp_ctx.vyxal_lists = False
+            repred_inps = [vy_repr(x, temp_ctx) for x in inps]
+            if online_mode:
+                ctx.online_output[1] += ", ".join(repred_inps) + " => "
+            else:
+                print(", ".join(repred_inps), end=" => ")
+            execute_vyxal(
+                file_name,
+                flags.replace("A", ""),
+                "\n".join(repred_inps) if online_mode else inps,
+                output_var,
+                online_mode,
+            )
+        sys.exit(0)
+
     if "e" in flags:  # Program is file name
         code = file_name
     elif "v" in flags:  # Open file using Vyxal encoding
@@ -126,14 +155,19 @@ def execute_vyxal(file_name, flags, inputs, output_var=None, online_mode=False):
 
     ctx.reverse_flag = "r" in flags
     ctx.number_as_range = "R" in flags
-    ctx.dictionary_compression = "D" not in flags
-    ctx.variable_length_1 = "V" in flags
     ctx.vectorise_boolify = "t" in flags  # see boolify in elements.py
     ctx.vyxal_lists = "P" not in flags
     ctx.print_decimals = "ḋ" in flags
     ctx.empty_input_is_zero = "?" not in flags
     ctx.array_inputs = "a" in flags
     ctx.double_zip_vectorize = "Z" in flags
+    ctx.utf8strings = "U" in flags
+
+    options = TranspilationOptions()
+    options.dict_compress = "D" not in flags
+    options.variables_as_digraphs = "V" in flags
+    options.utf8strings = ctx.utf8strings
+    ctx.transpilation_options = options
 
     if "2" in flags:
         ctx.default_arity = 2
@@ -143,9 +177,7 @@ def execute_vyxal(file_name, flags, inputs, output_var=None, online_mode=False):
         ctx.default_arity = 1
 
     try:
-        code = transpile(
-            code, ctx.dictionary_compression, ctx.variable_length_1
-        )
+        code = transpile(code, options)
     except Exception as e:  # skipcq: PYL-W0703
         if ctx.online:
             ctx.online_output[2] += "\n" + traceback.format_exc()
@@ -270,7 +302,8 @@ def repl():
     ctx.repl_mode = True
     while True:
         # Vyxal REPL ftw
-        line = transpile(input(">>> "))
+        # Empty options is still required
+        line = transpile(input(">>> "), TranspilationOptions())
         stack = []
         ctx.stacks.append(stack)  # Finally, a use case for assignment by
         # reference. Never thought I'd fine a time
